# CreateBillingDocumentFilesDeletionJobStatus

The status of the billing document file deletion job. 

## Enum

* `PENDING` (value: `'Pending'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


